/// @description back in.
/// @param t (0〜1)
/// @return back in value.
function backIn(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	return t * t * (2.70158 * t - 1.70158);
}

/// @description back out.
/// @param t (0〜1)
/// @return back out value.
function backOut(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	return 1 - (t - 1) * (t-1) * (-2.70158 * (t-1) - 1.70158);
}

/// @description bounce in.
/// @param t (0〜1)
/// @return bounce in value.
function bounceIn(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	var B1 = 1 / 2.75;
	var B2 = 2 / 2.75;
	var B3 = 1.5 / 2.75;
	var B4 = 2.5 / 2.75;
	var B5 = 2.25 / 2.75;
	var B6 = 2.625 / 2.75;

	t = 1 - t;
	if (t < B1) return 1 - 7.5625 * t * t;
	if (t < B2) return 1 - (7.5625 * (t - B3) * (t - B3) + .75);
	if (t < B4) return 1 - (7.5625 * (t - B5) * (t - B5) + .9375);
    
	return 1 - (7.5625 * (t - B6) * (t - B6) + .984375);
}

/// @description bounce out.
/// @param t (0〜1)
/// @return bounce out value.
function bounceOut(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	var B1 = 1 / 2.75;
	var B2 = 2 / 2.75;
	var B3 = 1.5 / 2.75;
	var B4 = 2.5 / 2.75;
	var B5 = 2.25 / 2.75;
	var B6 = 2.625 / 2.75;
	if (t < B1) return 7.5625 * t * t;
	if (t < B2) return 7.5625 * (t - B3) * (t - B3) + .75;
	if (t < B4) return 7.5625 * (t - B5) * (t - B5) + .9375;
    
	return 7.5625 * (t - B6) * (t - B6) + .984375;
}

/// @description cube in.
/// @param t (0〜1)
/// @return cube in value.
function cubeIn(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	return t * t * t;
}

/// @description cube out.
/// @param t (0〜1)
/// @return cube in value.
function cubeOut(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	return 1 + (t - 1) * (t - 1) * (t - 1)
}

/// @description elastic in.
/// @param t (0〜1)
/// @return elastic in value.
function elasticIn(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	var ELASTIC_AMPLITUDE = 1
	var ELASTIC_PERIOD = 0.4
	t -= 1
	return -(ELASTIC_AMPLITUDE * power(2, 10 * t) * sin( (t - (ELASTIC_PERIOD / (2 * pi) * arcsin(1 / ELASTIC_AMPLITUDE))) * (2 * pi) / ELASTIC_PERIOD));
}

/// @description elastic out.
/// @param t (0〜1)
/// @return elatic out value.
function elasticOut(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	var ELASTIC_AMPLITUDE = 1;
	var ELASTIC_PERIOD = 0.4;
	return (ELASTIC_AMPLITUDE * power(2, -10 * t) * sin((t - (ELASTIC_PERIOD / (2 * pi) * arcsin(1 / ELASTIC_AMPLITUDE))) * (2 * pi) / ELASTIC_PERIOD) + 1);
}

/// @description expo in.
/// @param t (0〜1)
/// @return expo in value.
function expoIn(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	return power(2, 10 * (t - 1));
}

/// @description expo out.
/// @param t (0〜1)
/// @return expo out value.
function expoOut(t) {
	if(t < 0) return 0;
	if(t > 1) return 1;

	return -power(2, -10*t) + 1;
}

